##  Calculation Templates
You can view calculation templates for AI agents in the Calculations section of the administration area.
Calculation Template | Description | Target Field | Logic
---|---|---|---
AI agent business value: cost savings | Calculates your AI agents' cost savings from usage and unit cost. | Total Expected Cost Savings | Usage x Cost Savings per Unit = Total Expected Cost Savings
AI agent business value: revenue increase | Calculates your AI agents' revenue increase from usage and unit revenue. | Total Expected Revenue Increase | Usage x Revenue Increase per Unit = Total Expected Revenue Increase
AI agent business value: risk reduction | Calculates your AI agents' risk reduction from usage and unit risk. | Total Expected Risk Reduction | Usage x Risk Reduction per Unit = Total Expected Risk Reduction


YesNo
Send
![close icon](https://consent.trustarc.com/get?name=sapglow-close-icon.png)
This site uses cookies and related technologies, as described in our Cookie Statement, for purposes that may include site operation, analytics, enhanced user experience, or advertising. You may choose to consent to our use of these technologies, or manage your own preferences.
Understood Manage Settings
[Privacy Statement](https://help.sap.com/docs/privacy)|[Cookie Statement](https://www.sap.com/about/legal/privacy/cookies.html)
